@@ -26,7 +26,7 @@ logger = logging.getLogger("sagemaker")
 
 
 class AutoML(object):
-    """A class for creating and interacting with SageMaker AutoML jobs"""
+    """A class for creating and interacting with SageMaker AutoML jobs."""
 
     def __init__(
         self,
@@ -178,13 +178,14 @@ class AutoML(object):
         return self._auto_ml_job_desc
 
     def best_candidate(self, job_name=None):
-        """Returns the best candidate of an AutoML job for a given name
+        """Returns the best candidate of an AutoML job for a given name.
 
         Args:
             job_name (str): The name of the AutoML job. If None, will use object's
                 _current_auto_ml_job_name.
+
         Returns:
-            dict: a dictionary with information of the best candidate
+            dict: A dictionary with information of the best candidate.
         """
         if self._best_candidate:
             return self._best_candidate
@@ -226,8 +227,9 @@ class AutoML(object):
                 Default to None.
             max_results (int): The number of candidates will be listed in results,
                 between 1 to 100. Default to None. If None, will return all the candidates.
+
         Returns:
-            list: A list of dictionaries with candidates information
+            list: A list of dictionaries with candidates information.
         """
         if job_name is None:
             job_name = self.current_job_name
@@ -260,8 +262,7 @@ class AutoML(object):
         predictor_cls=None,
         inference_response_keys=None,
     ):
-        """Creates a model from a given candidate or the best candidate
-        from the automl job
+        """Creates a model from a given candidate or the best candidate from the job.
 
         Args:
             name (str): The pipeline model name.
@@ -287,8 +288,7 @@ class AutoML(object):
                 keys will dictate the content order in the response.
 
         Returns:
-            PipelineModel object
-
+            PipelineModel object.
         """
         sagemaker_session = sagemaker_session or self.sagemaker_session
 
@@ -350,7 +350,7 @@ class AutoML(object):
         predictor_cls=None,
         inference_response_keys=None,
     ):
-        """Deploy a candidate to a SageMaker Inference Pipeline and return a Predictor
+        """Deploy a candidate to a SageMaker Inference Pipeline.
 
         Args:
             initial_instance_count (int): The initial number of instances to run
@@ -434,7 +434,6 @@ class AutoML(object):
 
         Raises (ValueError): raises ValueError if one of problem_type and job_objective is provided
             while the other is None.
-
         """
         if not (problem_type and job_objective) and (problem_type or job_objective):
             raise ValueError(
@@ -490,17 +489,18 @@ class AutoML(object):
 
     @classmethod
     def _check_inference_keys(cls, inference_response_keys, containers):
-        """Given an inference container list, checks if the pipeline supports the
-        requested inference keys
+        """Checks if the pipeline supports the inference keys for the containers.
+
+        Given inference response keys and list of containers, determines whether
+        the keys are supported.
 
         Args:
-            inference_response_keys (list): List of keys for inference response content
-            containers (list): list of inference container
+            inference_response_keys (list): List of keys for inference response content.
+            containers (list): list of inference container.
 
         Raises:
             ValueError, if one or more keys in inference_response_keys are not supported
             the inference pipeline.
-
         """
         if not inference_response_keys:
             return
@@ -528,8 +528,10 @@ class AutoML(object):
 
     @classmethod
     def validate_and_update_inference_response(cls, inference_containers, inference_response_keys):
-        """Validates the requested inference keys and updates inference containers to emit the
-        requested content in the inference response.
+        """Validates the requested inference keys and updates response content.
+
+        On validation, also updates the inference containers to emit appropriate response
+        content in the inference response.
 
         Args:
             inference_containers (list): list of inference containers
@@ -537,7 +539,6 @@ class AutoML(object):
 
         Raises:
             ValueError: if one or more of inference_response_keys are unsupported by the model
-
         """
         if not inference_response_keys:
             return
@@ -572,8 +573,10 @@ class AutoML(object):
 
 
 class AutoMLInput(object):
-    """Accepts parameters that specify an S3 input for an auto ml job and provides
-    a method to turn those parameters into a dictionary."""
+    """Accepts parameters that specify an S3 input for an auto ml job
+
+    Provides a method to turn those parameters into a dictionary.
+    """
 
     def __init__(self, inputs, target_attribute_name, compression=None):
         """Convert an S3 Uri or a list of S3 Uri to an AutoMLInput object.
@@ -704,12 +707,11 @@ class AutoMLJob(_Job):
         Args:
             inputs (str, list[str]): local path(s) or S3 uri(s) of input datasets.
             validate_uri (bool): indicates whether it is needed to validate S3 uri.
-            compression (str):
+            compression (str): Compression type of the input data.
             target_attribute_name (str): the target attribute name for classification
                 or regression.
 
         Returns (dict): a dict of AutoML InputDataConfig
-
         """
         if inputs is None:
             return None
@@ -758,7 +760,6 @@ class AutoMLJob(_Job):
             total_job_runtime_in_seconds (int): the total wait time of an AutoML job.
 
         Returns (dict): an AutoML CompletionCriteria.
-
         """
         stopping_condition = {"MaxCandidates": max_candidates}
 
@@ -777,6 +778,7 @@ class AutoMLJob(_Job):
 
     def wait(self, logs=True):
         """Wait for the AutoML job to finish.
+
         Args:
             logs (bool): indicate whether to output logs.
         """
